==> win32_Release_v4.0.0_r895.zip: data/scripts/buildings/plasma.lua <==
amta8  VrvioG`wrv+J$P9fnC7X/J86<U8H'U!	.]8L8Q?X+%/ٺҷ֢ǵ؝ݩŤײݭӾ߀UVX6iY{WwU!D<H=O*Yv⑾49JeсW'7GNb$$
kL%$䈤˟ԯ``R䔻nn]}v N>9//.:&'&3/-,:1ȟ11Ժd6PGHOt+M?^3V	-54uxXQyxGobBKcb]6=<=V\kCBC>4>±آˎâ֢à˙񀃲άfUeO/A4Yvr4H zyHq]10>M%D O8ye
lLqQaOyU--̵ֺߋuu~~zL)E$]}@`QzίݩzzV.,

ppa3V1]2Eb7662];].K?"T1R`HeQ}]pAr[phiV5K>2ac
~U4Y<zg
k2򄂧Üsr蔦BBj88bR`QP#0߬TY8%D*C.]sTR4S{WzW奈55Sa5Ը٠-*rQQ523/?)جñзҟ+m&LͥTUup42()nm:9ilKDDwWRz;36QUݼ.+y}UUTtqn)ʲ**(4ƽ??Q$
!5ffUꖖGsFO-NF=777D!M(K7DtNMN*O<H:U$Qa`	g _UQ_Bb9;VR
xo||ײYh뛸	'T$A$@`]}OǕvGV==6VV{1AAap$#0xTneJČ%!1Ἀ 7KO{{xxez_^*X-HeMDBcy!"": II}qt]!!|u ?{S<89_*D'OJO(M9mv{wwrZ.G*Ot A3T1ElfoxyeEo9920Oפ¬ߺ2pbCF*ַOkEݼߺ67\Y!6?l}>Q?Y0W$%aGsiD­ðĶà1;Ϋǡ+"(!Z'F"FkC&V3]9]Hz||TشݻҵBB23!;KDN;K/N:_|r1m냷cG:oTU R7vU03`zpXr><]!ʬ͡ҷoZrk5.-,  *#쿌WyQxT|Sw(RR&=U%Vx?ꚚpGMDMix;Z4f	}h
%bsW'(ܽWU`_w@Bf޸;۲ŀŪΫaElŅn,H|'̊?pǐ (ܨǨķIlkHfvaO//*
7y|v70:裏`aIɭ6yWiLE׾X6ɪMNb理10oPlsxP!"#<LL  bu#J9P2^;ehmfq_sr'+	x}®5	 )ml@bfp󃎩	{zRs.wt!heM}QuU>cuuv0B-@}	lp}h%D*K,I-onmdM;sfN<>2ѹ֤H[]2^2]*zf-OLOELELEuǁްֿѸ̵gsG[s#?cO:0ui%#-#`,M4Q#ncjNGMa9-9(񅢂8?4婡QU}x};S[ZzJfFkW_bL`hҶ#ze
l;noO Rr(@[PA 	wJ$M!`jƞ̿ɭ튢g.Kh
V~NxX\oϧ|5E<aOh9-Yz@cde!D)F*C0X4 8ap4Č,(pf|T 9EaOi󗞰 $.(QP|˓#:o-QƣD8w\ǢǩH[~4t|^deJ&&ݲѰ\=W_p<(8k=>2'۲yxLM6%uićy}gqDZA-L+!㧋I-/sX0 `eT9f| ֱV.:2dcH 0S38=<(VfLRP&dHέ̠0xxXJstZh^de	`oM󯗽ȼvn XpYrCmqZƾFBe))	
82;{~wbgQ}YT|E)ZTtEK{W7CAq]lEeXxt?wyI3AZr!#䐁卆P#"57 ovTLu0F#M9!I3oKa93R~k@d!oAhg!+sy4[?J&CniP:ոZszszNϗ򎎏 gPr^~.>4>2!%r6ZZr`gY:2byY[q|~w_'%m RrAk33ûu!#pwl.NsJf^Pr

2՞0XOiUp4,/+͍FDt8(ɭXU``@ֺbLM=\+Ea)nKmFԠǮڸ1R:ڵ_㼔ww ՠΧӃүkM\]u\r
 ٠&2.

H`-
(Hf֚4WU%6ڬcLIdk|(G*\T]mO;Y=<QQX<.*QkO>ꇇ,,/ycw?[i_en9aeWŇ8KIeEtDu"&BQmMXۿBEl%v݂6
 s].K?wxpgOgKBh$$ףּ澶ɓև-	^F|MqaLڴCu\`pXDE`]5?SSz]ï.vRʹ9,OgngJzjXKW/%HHAi!%pz_K
ʞ˯[qBǗ¤/!,B-
}	8	y+Oh.f!⣈t
 ק$jj^6|=tt\xpA8-9Ia'rTqAabƦգo!7!;:CW{S6^x/̀v?OOm"ף!yUihNBBu() ӶFbfaR+[>joǳWv~R)/p|z_X~!@-=R<oMcS7l9U9}|RION=qֺ}zX  T"#ɽ``Gb\aϐ펢f̨M윦YdWzQm3*=fe1ud7P5Qvβj0\]^oO3qp	3
pddGsFFLaLl u4k.v&i;o0u;n#|5{$w'f%`H 0em!@5[8P5GndmMK׻F$kN#::0WL<]>[guy-B5P"(M#GVVV

==> win32_Release_v4.0.1_r905.zip: data/scripts/buildings/plasma.lua <==
amta9  VrvioG`wrv+J$P9fnC7X/J86<U8H'U!	.]8L8Q?X+%/ٺҷ֢ǵ؝ݩŤײݭӾ߀UVX6iY{WwU!D<H=O*Yv⑾49JeсW'7GNb$$
kL%$䈤˟ԯ``R䔻nn]}v N>9//.:&'&3/-,:1ȟ11Ժd6PGHOt+M?^3V	-54uxXQyxGobBKcb]6=<=V\kCBC>4>±آˎâ֢à˙񀃲άfUeO/A4Yvr4H zyHq]10>M%D O8ye
lLqQaOyU--̵ֺߋuu~~zL)E$]}@`QzίݩzzV.,

ppa3V1]2Eb7662];].K?"T1R`HeQ}]pAr[phiV5K>2ac
~U4Y<zg
k2򄂧Üsr蔦BBj88bR`QP#0߬TY8%D*C.]sTR4S{WzW奈55Sa5Ը٠-*rQQ523/?)جñзҟ+m&LͥTUup42()nm:9ilKDDwWRz;36QUݼ.+y}UUTtqn)ʲ**(4ƽ??Q$
!5ffUꖖGsFO-NF=777D!M(K7DtNMN*O<H:U$Qa`	g _UQ_Bb9;VR
xo||ײYh뛸	'T$A$@`]}OǕvGV==6VV{1AAap$#0xTneJČ%!1Ἀ 7KO{{xxez_^*X-HeMDBcy!"": II}qt]!!|u ?{S<89_*D'OJO(M9mv{wwrZ.G*Ot A3T1ElfoxyeEo9920Oפ¬ߺ2pbCF*ַOkEݼߺ67\Y!6?l}>Q?Y0W$%aGsiD­ðĶà1;Ϋǡ+"(!Z'F"FkC&V3]9]Hz||TشݻҵBB23!;KDN;K/N:_|r1m냷cG:oTU R7vU03`zpXr><]!ʬ͡ҷoZrk5.-,  *#쿌WyQxT|Sw(RR&=U%Vx?ꚚpGMDMix;Z4f	}h
%bsW'(ܽWU`_w@Bf޸;۲ŀŪΫaElŅn,H|'̊?pǐ (ܨǨķIlkHfvaO//*
7y|v70:裏`aIɭ6yWiLE׾X6ɪMNb理10oPlsxP!"#<LL  bu#J9P2^;ehmfq_sr'+	x}®5	 )ml@bfp󃎩	{zRs.wt!heM}QuU>cuuv0B-@}	lp}h%D*K,I-onmdM;sfN<>2ѹ֤H[]2^2]*zf-OLOELELEuǁްֿѸ̵gsG[s#?cO:0ui%#-#`,M4Q#ncjNGMa9-9(񅢂8?4婡QU}x};S[ZzJfFkW_bL`hҶ#ze
l;noO Rr(@[PA 	wJ$M!`jƞ̿ɭ튢g.Kh
V~NxX\oϧ|5E<aOh9-Yz@cde!D)F*C0X4 8ap4Č,(pf|T 9EaOi󗞰 $.(QP|˓#:o-QƣD8w\ǢǩH[~4t|^deJ&&ݲѰ\=W_p<(8k=>2'۲yxLM6%uićy}gqDZA-L+!㧋I-/sX0 `eT9f| ֱV.:2dcH 0S38=<(VfLRP&dHέ̠0xxXJstZh^de	`oM󯗽ȼvn XpYrCmqZƾFBe))	
82;{~wbgQ}YT|E)ZTtEK{W7CAq]lEeXxt?wyI3AZr!#䐁卆P#"57 ovTLu0F#M9!I3oKa93R~k@d!oAhg!+sy4[?J&CniP:ոZszszNϗ򎎏 gPr^~.>4>2!%r6ZZr`gY:2byY[q|~w_'%m RrAk33ûu!#pwl.NsJf^Pr

2՞0XOiUp4,/+͍FDt8(ɭXU``@ֺbLM=\+Ea)nKmFԠǮڸ1R:ڵ_㼔ww ՠΧӃүkM\]u\r
 ٠&2.

H`-
(Hf֚4WU%6ڬcLIdk|(G*\T]mO;Y=<QQX<.*QkO>ꇇ,,/ycw?[i_en9aeWŇ8KIeEtDu"&BQmMXۿBEl%v݂6
 s].K?wxpgOgKBh$$ףּ澶ɓև-	^F|MqaLڴCu\`pXDE`]5?SSz]ï.vRʹ9,OgngJzjXKW/%HHAi!%pz_K
ʞ˯[qBǗ¤/!,B-
}	8	y+Oh.f!⣈t
 ק$jj^6|=tt\xpA8-9Ia'rTqAabƦգo!7!;:CW{S6^x/̀v?OOm"ף!yUihNBBu() ӶFbfaR+[>joǳWv~R)/p|z_X~!@-=R<oMcS7l9U9}|RION=qֺ}zX  T"#ɽ``Gb\aϐ펢f̨M윦YdWzQm3*=fe1ud7P5Qvβj0\]^oO3qp	3
pddGsFFLaLl u4k.v&i;o0u;n#|5{$w'f%`H 0em!@5[8P5GndmMK׻F$kN#::0WƏb*ۿڶӧsvjb=P?M(/RX=S7&&&
